===============
Contributors ✨
===============


Thanks goes to these wonderful people (`emoji key <https://allcontributors.org/docs/en/emoji-key>`_):

.. raw:: html

    <!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
    <!-- prettier-ignore-start -->
    <!-- markdownlint-disable -->
    <table>
      <tr>
        <td align="center"><a href="https://www.linkedin.com/in/alan-snow-55bb8726/"><img src="https://avatars3.githubusercontent.com/u/8699967?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Alan D. Snow</b></sub></a><br /><a href="https://github.com/corteva/rioxarray/commits?author=snowman2" title="Code">💻</a> <a href="#ideas-snowman2" title="Ideas, Planning, & Feedback">🤔</a> <a href="#question-snowman2" title="Answering Questions">💬</a> <a href="https://github.com/corteva/rioxarray/issues?q=author%3Asnowman2" title="Bug reports">🐛</a> <a href="https://github.com/corteva/rioxarray/commits?author=snowman2" title="Documentation">📖</a> <a href="#example-snowman2" title="Examples">💡</a> <a href="#maintenance-snowman2" title="Maintenance">🚧</a> <a href="https://github.com/corteva/rioxarray/pulls?q=is%3Apr+reviewed-by%3Asnowman2" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/corteva/rioxarray/commits?author=snowman2" title="Tests">⚠️</a></td>
        <td align="center"><a href="https://github.com/alfredoahds"><img src="https://avatars2.githubusercontent.com/u/16520854?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Alfredo Delos Santos</b></sub></a><br /><a href="#ideas-alfredoahds" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/corteva/rioxarray/pulls?q=is%3Apr+reviewed-by%3Aalfredoahds" title="Reviewed Pull Requests">👀</a></td>
        <td align="center"><a href="https://github.com/justingruca"><img src="https://avatars2.githubusercontent.com/u/32334907?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Justin Gruca</b></sub></a><br /><a href="https://github.com/corteva/rioxarray/pulls?q=is%3Apr+reviewed-by%3Ajustingruca" title="Reviewed Pull Requests">👀</a></td>
        <td align="center"><a href="https://github.com/JWCook"><img src="https://avatars0.githubusercontent.com/u/419936?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Jordan Cook</b></sub></a><br /><a href="https://github.com/corteva/rioxarray/commits?author=JWCook" title="Documentation">📖</a></td>
        <td align="center"><a href="https://github.com/LiamRMoore"><img src="https://avatars1.githubusercontent.com/u/32279503?v=4?s=100" width="100px;" alt=""/><br /><sub><b>LiamRMoore</b></sub></a><br /><a href="https://github.com/corteva/rioxarray/commits?author=LiamRMoore" title="Code">💻</a> <a href="https://github.com/corteva/rioxarray/commits?author=LiamRMoore" title="Tests">⚠️</a></td>
        <td align="center"><a href="https://12rambau.github.io/web-resume/"><img src="https://avatars3.githubusercontent.com/u/12596392?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Rambaud Pierrick</b></sub></a><br /><a href="https://github.com/corteva/rioxarray/commits?author=12rambau" title="Documentation">📖</a></td>
        <td align="center"><a href="https://sites.google.com/site/mwtoews/"><img src="https://avatars.githubusercontent.com/u/895458?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Mike Taves</b></sub></a><br /><a href="https://github.com/corteva/rioxarray/commits?author=mwtoews" title="Code">💻</a> <a href="https://github.com/corteva/rioxarray/commits?author=mwtoews" title="Documentation">📖</a> <a href="#maintenance-mwtoews" title="Maintenance">🚧</a></td>
      </tr>
      <tr>
        <td align="center"><a href="https://github.com/BENR0"><img src="https://avatars.githubusercontent.com/u/12115839?v=4?s=100" width="100px;" alt=""/><br /><sub><b>BENR0</b></sub></a><br /><a href="https://github.com/corteva/rioxarray/issues?q=author%3ABENR0" title="Bug reports">🐛</a></td>
        <td align="center"><a href="https://github.com/Kirill888"><img src="https://avatars.githubusercontent.com/u/1428024?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Kirill Kouzoubov</b></sub></a><br /><a href="https://github.com/corteva/rioxarray/pulls?q=is%3Apr+reviewed-by%3AKirill888" title="Reviewed Pull Requests">👀</a></td>
        <td align="center"><a href="https://github.com/Zionett"><img src="https://avatars.githubusercontent.com/u/9539198?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Sangzi Liang</b></sub></a><br /><a href="https://github.com/corteva/rioxarray/pulls?q=is%3Apr+reviewed-by%3AZionett" title="Reviewed Pull Requests">👀</a></td>
        <td align="center"><a href="https://sites.google.com/view/raybellwaves/home"><img src="https://avatars.githubusercontent.com/u/17162724?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ray Bell</b></sub></a><br /><a href="https://github.com/corteva/rioxarray/commits?author=raybellwaves" title="Documentation">📖</a></td>
        <td align="center"><a href="https://github.com/baloola"><img src="https://avatars.githubusercontent.com/u/28819736?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Mussab Abdalla</b></sub></a><br /><a href="https://github.com/corteva/rioxarray/commits?author=baloola" title="Documentation">📖</a></td>
      </tr>
    </table>

    <!-- markdownlint-restore -->
    <!-- prettier-ignore-end -->

    <!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the `all-contributors <https://github.com/all-contributors/all-contributors>`_ specification. Contributions of any kind welcome!
